@@ -4,6 +4,10 @@ from typing import Literal, Type, TypeVar
 from pydantic import BaseSettings
 
 
+class ConfigError(Exception):
+    pass
+
+
 class AuthConfig(BaseSettings):
     url: str
     cookie_domain: str
